========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/badges/oslo.log.svg
    :target: https://governance.openstack.org/reference/tags/index.html

.. Change things from this point on

================================
oslo.log -- Oslo Logging Library
================================

.. image:: https://img.shields.io/pypi/v/oslo.log.svg
    :target: https://pypi.python.org/pypi/oslo.log/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/oslo.log.svg
    :target: https://pypi.python.org/pypi/oslo.log/
    :alt: Downloads

The oslo.log (logging) configuration library provides standardized
configuration for all openstack projects. It also provides custom
formatters, handlers and support for context specific
logging (like resource id's etc).

* Free software: Apache license
* Documentation: https://docs.openstack.org/oslo.log/latest
* Source: https://git.openstack.org/cgit/openstack/oslo.log
* Bugs: https://bugs.launchpad.net/oslo.log
